from Components.ActionMap import ActionMap
from Components.EpgList import EPG_TYPE_SIMILAR, EPG_TYPE_MULTI
from Components.Sources.StaticText import StaticText
from Components.Sources.Event import Event
from Components.Label import Label
from Components.config import config
from Screens.ChannelSelection import ChannelSelectionBase, ChannelSelectionRadio, SelectionEventInfo, MODE_TV, MODE_RADIO, ChannelSelectionEPG
from Screens.EpgSelection import EPGSelection
from Screens.EventView import EventViewEPGSelect, EventViewSimple
from Screens.Screen import Screen
from Components.Pixmap import Pixmap
from enigma import eServiceReference, eServiceCenter, iServiceInformation, eEPGCache
from ServiceReference import ServiceReference
from re import compile
from time import time

try:
	from Plugins.Extensions.EPGSearch.EPGSearch import EPGSearch
except:
	EPGSearch = None

class MerlinRadioChannelSelection(ChannelSelectionRadio, ChannelSelectionEPG, SelectionEventInfo):
	skin = """
		<screen name="MerlinRadioChannelSelection" position="center,50" size="820,360" title="">
			<ePixmap pixmap="skin_default/buttons/red.png" position="10,5" size="200,40" alphatest="on" />
			<ePixmap pixmap="skin_default/buttons/green.png" position="210,5" size="200,40" alphatest="on" />
			<ePixmap pixmap="skin_default/buttons/yellow.png" position="410,5" size="200,40" alphatest="on" />
			<ePixmap pixmap="skin_default/buttons/blue.png" position="610,5" size="200,40" alphatest="on" />
			<widget source="key_red" render="Label" position="10,5" size="200,40" zPosition="1" font="Regular;20" halign="center" valign="center" backgroundColor="#9f1313" transparent="1" shadowColor="#000000" shadowOffset="-2,-2" />
			<widget source="key_green" render="Label" position="210,5" size="200,40" zPosition="1" font="Regular;20" halign="center" valign="center" backgroundColor="#1f771f" transparent="1" shadowColor="#000000" shadowOffset="-2,-2" />
			<widget source="key_yellow" render="Label" position="410,5" size="200,40" zPosition="1" font="Regular;20" halign="center" valign="center" backgroundColor="#a08500" transparent="1" shadowColor="#000000" shadowOffset="-2,-2" />
			<widget source="key_blue" render="Label" position="610,5" size="200,40" zPosition="1" font="Regular;20" halign="center" valign="center" backgroundColor="#18188b" transparent="1" shadowColor="#000000" shadowOffset="-2,-2" />
			<eLabel position="10,50" size="800,1" backgroundColor="#aaaaaa" />
			<widget name="list" position="10,55" size="800,225" enableWrapAround="1" scrollbarMode="showOnDemand" />
			<eLabel position="10,290" size="800,1" backgroundColor="#aaaaaa" />
			<widget source="introduction" render="Label" position="10,300" size="800,25" font="Regular;22" halign="center" />
		</screen>"""

	def __init__(self, session, infobar=None):
		ChannelSelectionRadio.__init__(self, session, infobar)
		ChannelSelectionEPG.__init__(self)
		SelectionEventInfo.__init__(self)
		
		self["ChannelSelectEPGActions"] = ActionMap(["ChannelSelectEPGActions"],
		{
			"showEPGList": self.showEPGList,
		})
		
		self["key_red"] = StaticText(_("All"))
		self["key_green"] = StaticText(_("Satellites"))
		self["key_yellow"] = StaticText(_("Providers"))
		self["key_blue"] = StaticText(_("Favourites"))
		self["introduction"] = StaticText(_("Press OK to select channel.") )
		self["titleShort"] = StaticText()
		
		self["list"].onSelectionChanged.append(self.updateSummary)
		self.onShown.append(self.updateSummary)	
		
	def showEPGList(self):
		ref=self.getCurrentSelection()
		if ref:
			if config.merlin2.channelselection_eventinfo.value: # EventInfo in Channelselection
				epgcache = eEPGCache.getInstance()
				newEvent = epgcache.lookupEventTime(ref, -1) 
				# todo: implement MerlinEventViewEPGSelect
				self.session.open(MerlinRadioEventViewEPGSelect, newEvent, ServiceReference(ref),None ,self.openSingleServiceEPG, self.openMultiServiceEPG, self.openSimilarList)
			else:
				self.savedService = ref
				self.session.openWithCallback(self.SingleServiceEPGClosed, MerlinRadioEPGSelection, ref, serviceChangeCB=self.changeServiceCB)
				
	def openSingleServiceEPG(self):
		ref=self.getCurrentSelection()
		if ref:
			self.savedService = ref
			self.session.openWithCallback(self.SingleServiceEPGClosed, MerlinRadioEPGSelection, ref, serviceChangeCB=self.changeServiceCB)
			
	def openMultiServiceEPG(self):
		services = self.getBouquetServices(self.getRoot())
		if services:
			self.session.open(MerlinRadioEPGSelection, services, self.zapToService)

	def buildTitleString(self):
		titleStr = self.getTitle()
		pos = titleStr.find(']')
		if pos == -1:
			pos = titleStr.find(')')
		if pos != -1:
			titleStr = titleStr[:pos+1]
			Len = len(self.servicePath)
			if Len > 0:
				base_ref = self.servicePath[0]
				if Len > 1:
					end_ref = self.servicePath[Len-1]
				else:
					end_ref = None
				nameStr = self.getServiceName(base_ref)
				titleStr += ' ' + nameStr
				if end_ref is not None:
					if Len > 2:
						titleStr += '/../'
					else:
						titleStr += '/'
					nameStr = self.getServiceName(end_ref)
					titleStr += nameStr
				self.setTitle(_(titleStr))
				self.summaries.setTitle(_(nameStr))
				
	def createSummary(self):
		return MerlinRadioChannelSelectionLCDScreen	
		
	def updateSummary(self):
		text = ""
		event = ""
		eventRef = None
		ref = self.getCurrentSelection()
		self.summaries.setText(text, event)

class MerlinRadioChannelSelectionLCDScreen(Screen):
	skin = 	"""<screen name="MerlinRadioChannelSelectionLCDScreen" position="0,0" size="400,240" id="3">
			<widget name="summaryTitle" position="0,0" size="350,30" font="Regular;20" />
			<widget source="parent.ServiceEvent" position="0,30" size="400,30" font="MRLCD;25" render="Label">
				<convert type="ServiceName">Name</convert>
			</widget>
			<widget render="Picon" source="parent.ServiceEvent" path="picon_50x30" position="350,0" size="50,30" alphatest="on">
				<convert type="RefToPiconName" />
			</widget>
			<widget source="parent.ServiceEvent" render="Label" position="0,60" size="400,50" font="MRLCD;20">
				<convert type="EventName">Name</convert>
			</widget>			
			<widget pixmap="/usr/lib/enigma2/python/Plugins/Extensions/MerlinRadio/progress.png" source="parent.ServiceEvent" render="Progress" position="0,110" size="340,20" borderWidth="1">
				<convert type="EventTime">Progress</convert>
			</widget>		
			<widget font="Regular;16" halign="right" position="340,110" render="Label" size="60,20" source="parent.ServiceEvent" transparent="1" foregroundColor="#0064c7">
				<convert type="EventTime">Remaining</convert>
				<convert type="RemainingToText">InMinutes</convert>
			</widget>			
			<widget font="MRLCD;15" foregroundColor="#00ffa400" position="0,140" render="Label" size="400,40" source="parent.RdsDecoder" transparent="0" halign="center">
				<convert type="RdsInfo">RadioText</convert>
			</widget>	
			<widget name="red" position="0,190" size="100,50" font="Regular;18" backgroundColor="#f23d21" foregroundColor="#000000" halign="center" />
			<widget name="green" position="100,190" size="100,50" font="Regular;18"  backgroundColor="#389416" foregroundColor="#000000" halign="center" />
			<widget name="yellow" position="200,190" size="100,50" font="Regular;18" backgroundColor="#e6bd00" foregroundColor="#000000" halign="center" />
			<widget name="blue" position="300,190" size="100,50" font="Regular;18" backgroundColor="#0064c7" foregroundColor="#000000" halign="center" />
		</screen>"""		

	def __init__(self,session, parent):
		Screen.__init__(self, session, parent = parent)
		
		# todo: appy same logic like for other screens
		self["red"] = Label(_("All"))
		self["green"] = Label(_("Satellites"))
		self["yellow"] = Label(_("Providers"))
		self["blue"] = Label(_("Favourites"))
		self["summaryTitle"] = Label(_("Channel Selection"))
		
	def setText(self, text,event):
		pass
		
	def setTitle(self, title):
		self["summaryTitle"].setText(title)
		
	def setButtons(self, red=None, green=None, yellow=None, blue=None):
		if red is not None:
			self["red"].setText(red)
		if green is not None:
			self["green"].setText(green)
		if yellow is not None:
			self["yellow"].setText(yellow)
		if blue is not None:
			self["blue"].setText(blue)

class MerlinRadioEventViewSimple(EventViewSimple):
	def __init__(self, session, Event, Ref, callback=None, similarEPGCB=None):
		EventViewSimple.__init__(self, session, Event, Ref, callback=None, similarEPGCB=None)

		self.Event = Event
		self.onShown.append(self.updateSummary)	

	def createSummary(self):
		return MerlinRadioEventViewLCDScreen
		
	def updateSummary(self):
		self.summaries.setText(self.Event)
		
class MerlinRadioEventViewLCDScreen(Screen):
	skin = """	<screen name="MerlinRadioEventViewLCDScreen" position="0,0" size="400,240" id="3">
			<!-- widget source="parent.Title" position="0,0" size="400,30" font="Regular;20" render="Label" / -->
			<widget source="parent.Service" position="0,0" size="340,30" font="Regular;25" render="Label">
				<convert type="ServiceName">Name</convert>
			</widget>
			
			<widget source="myEvent" render="Label" position="0,30" size="340,25" font="Regular;20" transparent="1">
				<convert type="EventName">Name</convert>
			</widget>
			<widget font="Regular;16" halign="right" position="340,0" render="Label" size="60,20" source="myEvent" transparent="1" >
				<convert type="EventTime">StartTime</convert>
				<convert type="ClockToText">Default</convert>
			</widget>
			<widget font="Regular;16" halign="right" position="340,20" render="Label" size="60,20" source="myEvent" transparent="1">
				<convert type="EventTime">EndTime</convert>
				<convert type="ClockToText">Default</convert>
			</widget>		
			<widget font="Regular;16" halign="right" position="340,40" render="Label" size="60,20" source="myEvent" transparent="1">
				<convert type="EventTime">Duration</convert>
				<convert type="ClockToText">InMinutes</convert>
			</widget>
			<widget font="Regular;18" valign="top" position="0,70" render="Label" size="400,120" source="myEvent" transparent="1">
				<convert type="EventName">FullDescription</convert>
			</widget>
			<widget name="red" position="0,190" size="100,50" font="Regular;18" backgroundColor="#f23d21" foregroundColor="#000000" halign="center" />
			<widget name="green" position="100,190" size="100,50" font="Regular;18"  backgroundColor="#389416" foregroundColor="#000000" halign="center" />
			<widget name="yellow" position="200,190" size="100,50" font="Regular;18" backgroundColor="#e6bd00" foregroundColor="#000000" halign="center" />
			<widget name="blue" position="300,190" size="100,50" font="Regular;18" backgroundColor="#0064c7" foregroundColor="#000000" halign="center" />
		</screen>"""	
	def __init__(self,session, parent):
		Screen.__init__(self, session, parent = parent)
		self.parent = parent
		self["red"] = Label()
		self["green"] = Label()
		self["yellow"] = Label()
		self["blue"] = Label()
		self["myEvent"] = Event()
		
	def setText(self, event):
		self["myEvent"].newEvent(event)
		self["green"].setText(self.parent["key_green"].getText())

class MerlinRadioEventViewEPGSelect(EventViewEPGSelect):
	def __init__(self, session, Event, Ref, callback=None, singleEPGCB=None, multiEPGCB=None, similarEPGCB=None):
		EventViewEPGSelect.__init__(self, session, Event, Ref, callback=None, singleEPGCB=None, multiEPGCB=None, similarEPGCB=None)

		self["epgactions"] = ActionMap(["EventViewEPGActions"],
			{
				"openSingleServiceEPG": singleEPGCB,
				"openMultiServiceEPG": multiEPGCB,
			})

		self.Event = Event
		self.onShown.append(self.updateSummary)	

	def createSummary(self):
		return MerlinRadioEventViewEPGSelectLCDScreen
		
	def updateSummary(self):
		self.summaries.setText(self.Event)
		
class MerlinRadioEventViewEPGSelectLCDScreen(Screen):
	skin = """	<screen name="MerlinReadioEventViewEPGSelectLCDScreen" position="0,0" size="400,240" id="3">
			<!-- widget source="parent.Title" position="0,0" size="400,30" font="Regular;20" render="Label" / -->
			<widget source="parent.Service" position="0,0" size="340,30" font="Regular;25" render="Label">
				<convert type="ServiceName">Name</convert>
			</widget>
			
			<widget source="myEvent" render="Label" position="0,30" size="340,25" font="Regular;20" transparent="1">
				<convert type="EventName">Name</convert>
			</widget>
			<widget font="Regular;16" halign="right" position="340,0" render="Label" size="60,20" source="myEvent" transparent="1" >
				<convert type="EventTime">StartTime</convert>
				<convert type="ClockToText">Default</convert>
			</widget>
			<widget font="Regular;16" halign="right" position="340,20" render="Label" size="60,20" source="myEvent" transparent="1">
				<convert type="EventTime">EndTime</convert>
				<convert type="ClockToText">Default</convert>
			</widget>		
			<widget font="Regular;16" halign="right" position="340,40" render="Label" size="60,20" source="myEvent" transparent="1">
				<convert type="EventTime">Duration</convert>
				<convert type="ClockToText">InMinutes</convert>
			</widget>
			<widget font="Regular;18" valign="top" position="0,70" render="Label" size="400,120" source="myEvent" transparent="1">
				<convert type="EventName">FullDescription</convert>
			</widget>
			<widget name="red" position="0,190" size="100,50" font="Regular;18" backgroundColor="#f23d21" foregroundColor="#000000" halign="center" />
			<widget name="green" position="100,190" size="100,50" font="Regular;18"  backgroundColor="#389416" foregroundColor="#000000" halign="center" />
			<widget name="yellow" position="200,190" size="100,50" font="Regular;18" backgroundColor="#e6bd00" foregroundColor="#000000" halign="center" />
			<widget name="blue" position="300,190" size="100,50" font="Regular;18" backgroundColor="#0064c7" foregroundColor="#000000" halign="center" />
		</screen>"""	
	def __init__(self,session, parent):
		Screen.__init__(self, session, parent = parent)
		self.parent = parent
		self["red"] = Label()
		self["green"] = Label()
		self["yellow"] = Label()
		self["blue"] = Label()
		self["myEvent"] = Event()
		
	def setText(self, event):
		self["myEvent"].newEvent(event)
		self["green"].setText(self.parent["key_green"].getText())
		self["yellow"].setText(self.parent["key_yellow"].getText())
		self["blue"].setText(self.parent["key_blue"].getText())

class MerlinRadioEPGSelection(EPGSelection):
	def __init__(self, session, service, zapFunc=None, eventid=None, bouquetChangeCB=None, serviceChangeCB=None):
		EPGSelection.__init__(self, session, service, zapFunc=None, eventid=None, bouquetChangeCB=None, serviceChangeCB=None)
		self.skinName = "EPGSelection"
		
		self["list"].onSelChanged.append(self.updateSummary)

		if EPGSearch is not None:
			if self.type != EPG_TYPE_MULTI and config.plugins.epgsearch.add_search_to_epg.value:
				self["epgsearch_actions"] = ActionMap(["EPGSelectActions"],
					{
						"blue": self.bluePressed,
					})			

	def bluePressed(self):
		cur = self["list"].getCurrent()
		if cur[0] is not None:
			name = cur[0].getEventName()
		else:
			name = ''
		self.session.open(MerlinRadioEPGSearch, name)

	def infoKeyPressed(self):
		cur = self["list"].getCurrent()
		event = cur[0]
		service = cur[1]
		if event is not None:
			if self.type != EPG_TYPE_SIMILAR:
				self.session.open(MerlinRadioEventViewSimple, event, service, self.eventViewCallback, self.openSimilarList)
			else:
				self.session.open(MerlinRadioEventViewSimple, event, service, self.eventViewCallback)

	def setSortDescription(self):
		if self.sort_type == 1:
			# TRANSLATORS: This must fit into the header button in the EPG-List
			self["key_yellow"].setText(_("Sort Time"))
		else:
			# TRANSLATORS: This must fit into the header button in the EPG-List
			self["key_yellow"].setText(_("Sort A-Z"))
		self.summaries.setText()
	
	def createSummary(self):
		return MerlinRadioEPGLCDScreen
		
	def updateSummary(self):
		self.summaries.setText()
		
class MerlinRadioEPGLCDScreen(Screen):
	skin = """	<screen name="MerlinRadioEPGLCDScreen" position="0,0" size="400,240" id="3">
			<widget source="parent.Title" position="0,0" size="400,30" font="Regular;20" render="Label" />
			<widget source="parent.Service" position="0,30" size="400,30" font="Regular;25" render="Label">
				<convert type="ServiceName">Name</convert>
			</widget>
			
			<widget source="parent.Event" render="Label" position="0,60" size="400,50" font="Regular;20">
				<convert type="EventName">Name</convert>
			</widget>			
			<!--widget source="parent.Event" render="Progress" position="0,110" size="400,20" backgroundColor="#aaaaaa">
				<convert type="EventTime">Progress</convert>
			</widget-->
			<widget font="Regular;16" halign="right" position="0,110" render="Label" size="260,20" source="parent.Event" transparent="1">
				<convert type="EventTime">StartTime</convert>
				<convert type="ClockToText">Format: %a, %d.%m., %H:%M</convert>
			</widget>
			<widget font="Regular;16" halign="right" position="270,110" render="Label" size="60,20" source="parent.Event" transparent="1">
				<convert type="EventTime">EndTime</convert>
				<convert type="ClockToText">Default</convert>
			</widget>		
			<widget font="Regular;16" halign="right" position="340,110" render="Label" size="60,20" source="parent.Event" transparent="1">
				<convert type="EventTime">Duration</convert>
				<convert type="ClockToText">InMinutes</convert>
			</widget>			
			<widget name="red" position="0,190" size="100,50" font="Regular;18" backgroundColor="#f23d21" foregroundColor="#000000" halign="center" />
			<widget name="green" position="100,190" size="100,50" font="Regular;18"  backgroundColor="#389416" foregroundColor="#000000" halign="center" />
			<widget name="yellow" position="200,190" size="100,50" font="Regular;18" backgroundColor="#e6bd00" foregroundColor="#000000" halign="center" />
			<widget name="blue" position="300,190" size="100,50" font="Regular;18" backgroundColor="#0064c7" foregroundColor="#000000" halign="center" />
		</screen>"""	

	def __init__(self,session, parent):
		Screen.__init__(self, session, parent = parent)
		self.parent = parent
		
		self["red"] = Label(self.parent["key_red"].getText())
		self["green"] = Label(self.parent["key_green"].getText())
		self["yellow"] = Label(self.parent["key_yellow"].getText())
		self["blue"] = Label(self.parent["key_blue"].getText())
		
	def setText(self):
		self["red"].setText(self.parent["key_red"].getText())
		self["yellow"].setText(self.parent["key_yellow"].getText())
		self["green"].setText(self.parent["key_green"].getText())
		self["blue"].setText(self.parent["key_blue"].getText())			

if EPGSearch is not None:
	class MerlinRadioEPGSearch(EPGSearch):
		def __init__(self, session, *args):
			EPGSearch.__init__(self, session, *args)
			
			self["list"].onSelChanged.append(self.updateSummary)

		"""
		def infoKeyPressed(self):
			cur = self["list"].getCurrent()
			event = cur[0]
			service = cur[1]
			if event is not None:
				from Screens.InfoBar import InfoBar
				self.session.open(MerlinRadioEventViewEPGSelect, event, service, self.eventViewCallback, self.openSingleServiceEPG, InfoBar.instance.openMultiServiceEPG, self.openSimilarList)
		"""
			
		def createSummary(self):
			return MerlinRadioEPGSearchLCDScreen
			
		def updateSummary(self):
			self.summaries.setText()
			
	class MerlinRadioEPGSearchLCDScreen(Screen):
		skin = 	"""	<screen name="MerlinRadioEPGSearchLCDScreen" position="0,0" size="400,240" id="3">
				<widget source="parent.Event" render="Label" position="0,60" size="400,50" font="Regular;20">
					<convert type="EventName">Name</convert>
				</widget>	
				<widget font="Regular;16" halign="right" position="0,110" render="Label" size="300,20" source="parent.Event" transparent="1">
					<convert type="EventTime">StartTime</convert>
					<convert type="ClockToText">Format: %a, %d.%m., %H:%M</convert>
				</widget>
				<widget font="Regular;16" halign="right" position="340,110" render="Label" size="60,20" source="parent.Event" transparent="1">
					<convert type="EventTime">Duration</convert>
					<convert type="ClockToText">InMinutes</convert>
				</widget>						
				<widget source="parent.Title" position="0,0" size="400,30" font="Regular;20" render="Label" />
				<widget name="red" position="0,190" size="100,50" font="Regular;18" backgroundColor="#f23d21" foregroundColor="#000000" halign="center" />
				<widget name="green" position="100,190" size="100,50" font="Regular;18"  backgroundColor="#389416" foregroundColor="#000000" halign="center" />
				<widget name="yellow" position="200,190" size="100,50" font="Regular;18" backgroundColor="#e6bd00" foregroundColor="#000000" halign="center" />
				<widget name="blue" position="300,190" size="100,50" font="Regular;18" backgroundColor="#0064c7" foregroundColor="#000000" halign="center" />
			</screen>"""		

		def __init__(self,session, parent):
			Screen.__init__(self, session, parent = parent)	
			self.parent = parent
		
			self["red"] = Label(self.parent["key_red"].getText())
			self["green"] = Label(self.parent["key_green"].getText())		
			self["yellow"] = Label(self.parent["key_yellow"].getText())		
			self["blue"] = Label(self.parent["key_blue"].getText())
			self["myEvent"] = Event()
			
		def setText(self, event=None):
			#self["myEvent"].newEvent(event)
			self["red"].setText(self.parent["key_red"].getText())
			self["green"].setText(self.parent["key_green"].getText())		
			self["yellow"].setText(self.parent["key_yellow"].getText())		
			self["blue"].setText(self.parent["key_blue"].getText())
			