from Components.ActionMap import ActionMap, HelpableActionMap
from Components.Button import Button
from Components.ConfigList import ConfigListScreen
from Components.Label import Label
from Components.Pixmap import Pixmap
from Components.config import config, ConfigSubsection, getConfigListEntry, ConfigYesNo
from Plugins.Plugin import PluginDescriptor
from Screens.HelpMenu import HelpableScreen
from Screens.InfoBar import InfoBar
from Screens.MessageBox import MessageBox
from Screens.Screen import Screen
from Tools.Directories import fileExists
from os import listdir
import re

# imports for channelselection
from merlinradiochannelselection import MerlinRadioChannelSelection

config.plugins.merlinradio = ConfigSubsection()
config.plugins.merlinradio.startwithradio = ConfigYesNo(default = True)
config.plugins.merlinradio.showinplugins = ConfigYesNo(default = True)
config.plugins.merlinradio.showinmain = ConfigYesNo(default = False)

baseInfoBar__init__ = None
mysession = None

def main(session,**kwargs):
    session.open(MerlinRadioChannelSelection)
    
def startMerlinRadio():
	main(mysession)

def mainmenu(menuid, **kwargs):
	if menuid != "mainmenu":
		return []
	return [(_("Merlin Radio"), main, "MerlinRadio", 40)]
   
def setup(menuid, **kwargs):
	if menuid != "merlin":
		return []
	return [(_("Merlin Radio Setup"), openconfig, "MerlinRadio", 95)]
	
def openconfig(session, **kwargs):
	session.open(MerlinRadioSetup)
	
def sessionstart(reason, **kwargs):
	if reason == 0:
		from enigma import addFont
		addFont("/usr/share/fonts/scoreboard.ttf", "MRLCD", 100, False)
		if config.plugins.merlinradio.startwithradio.value:
			if "session" in kwargs:
				global mysession, baseInfoBar__init__ 
				mysession = kwargs["session"]
				if baseInfoBar__init__ is None:
					baseInfoBar__init__ = InfoBar.__init__
				InfoBar.__init__ = InfoBar__init__
		config.plugins.merlinradio.startwithradio.addNotifier(buttonChanged, initial_call = False)
				
def InfoBar__init__(self, session):
	baseInfoBar__init__(self, session)
	if isinstance(self, InfoBar) and config.plugins.merlinradio.startwithradio.value:
		InfoBar.instance["actions"].actions["showRadio"] = startMerlinRadio

def buttonChanged(configElement = None):
	from Screens.InfoBar import InfoBar
	if configElement.value:
		InfoBar.instance["actions"].actions["showRadio"] = startMerlinRadio
	else:
		InfoBar.instance["actions"].actions["showRadio"] = InfoBar.instance.showRadio
	
class MerlinRadioSetup(Screen, HelpableScreen, ConfigListScreen):
	skin = """
		<screen position="center,center" size="500,160" title="Merlin Radio Setup" >
			<ePixmap pixmap="skin_default/buttons/red.png" position="10,5" size="235,40" alphatest="on"/>
			<ePixmap pixmap="skin_default/buttons/green.png" position="245,5" size="235,40" alphatest="on"/>
			<widget name="key_red" position="10,5" size="235,40" zPosition="1" font="Regular;20" halign="center" valign="center" backgroundColor="#9f1313" transparent="1" shadowColor="black" shadowOffset="-2,-2" />
			<widget name="key_green" position="245,5" size="235,40" zPosition="1" font="Regular;20" halign="center" valign="center" backgroundColor="#1f771f" transparent="1" shadowColor="black" shadowOffset="-2,-2" />
			<eLabel	position="10,50" size="480,1" backgroundColor="grey"/>
			<widget name="config" position="10,60" size="480,70" enableWrapAround="1" scrollbarMode="showOnDemand"/>
		</screen>
			"""
			
	def __init__(self, session, *args):
		Screen.__init__(self, session)
		HelpableScreen.__init__(self)
		
		self.session = session
		
		self["key_red"] = Button(_("Cancel"))
		self["key_green"] = Button(_("Save"))
		
		self["WizardActions"] = HelpableActionMap(self, "WizardActions",
			{
				"back":	(self.cancelSettings, _("Close without saving")),
				"ok":	(self.saveSettings, _("Save and close")),
			}, -1)
			
		self["ColorActions"] = HelpableActionMap(self, "ColorActions",
			{
				"red":	(self.cancelSettings, _("Close without saving")),
				"green":	(self.saveSettings, _("Save and close")),
			}, -1)
			
		self.list = []
		self.list.append(getConfigListEntry(_("Start Merlin Radio with Radio key"), config.plugins.merlinradio.startwithradio))
		self.list.append(getConfigListEntry(_("Show Merlin Radio in plugin menu"), config.plugins.merlinradio.showinplugins))
		self.list.append(getConfigListEntry(_("Show Merlin Radio in main menu"), config.plugins.merlinradio.showinmain))
		ConfigListScreen.__init__(self, self.list)
		self["config"].setList(self.list)
		
	def saveSettings(self):
		for x in self["config"].list:
			x[1].save()
		self.close()
		
	def cancelSettings(self):
		for x in self["config"].list:
			x[1].cancel()
		self.close()
    
def Plugins(**kwargs):
    list = [
    	PluginDescriptor(name=_("Merlin Radio Setup"), description=_("Configure Merlin Radio"), where = [PluginDescriptor.WHERE_MENU], fnc=setup, icon = "MerlinRadio.svg"),
    	PluginDescriptor(where = [PluginDescriptor.WHERE_SESSIONSTART], fnc=sessionstart)
    	]
    if config.plugins.merlinradio.showinplugins.value:
    	list.append(PluginDescriptor(name="Merlin Radio", description=_("A plugin to play DVB-radio"), where = [PluginDescriptor.WHERE_PLUGINMENU], fnc=main, icon = "MerlinRadio.svg"))
    if config.plugins.merlinradio.showinmain.value:
    	list.append(PluginDescriptor(name=_("Merlin Radio"), description=_("Start Merlin Radio"), where = [PluginDescriptor.WHERE_MENU], fnc=mainmenu, icon = "MerlinRadio.svg"))
    return list
    